==> pycoze-0.1.94-py3-none-any.whl: pycoze/access/tool_for_bot.py <==
import sys
import os
import importlib
from langchain.agents import tool as _tool
import types
import langchain_core


class ChangeDirectoryAndPath:
    """Context manager to change the current working directory and sys.path."""

    def __init__(self, module_path):
        self.module_path = module_path
        self.old_path = None

    def __enter__(self):
        self.old_path = os.getcwd()
        sys.path.insert(0, self.module_path)
        os.chdir(self.module_path)
        return self

    def __exit__(self, exc_type, exc_value, traceback):
        sys.path.remove(self.module_path)
        os.chdir(self.old_path)


def wrapped_tool(tool, module_path):
    """Wrap the tool function to include additional logging and path management."""
    original_tool_function = tool.func

    def _wrapped_tool(*args, **kwargs):
        print(f"调用了{tool.name}")
        with ChangeDirectoryAndPath(module_path):
            result = original_tool_function(*args, **kwargs)
        print(f"{tool.name}调用完毕,结果为:", result)
        return result

    return _wrapped_tool


def import_tools(tool_id):
    """Import tools from a specified tool_id."""
    tool_base_path = "../../tool"
    module_path = os.path.join(tool_base_path, tool_id)
    module_path = os.path.normpath(os.path.abspath(module_path))

    if not os.path.exists(module_path):
        print(f"Tool {tool_id} not found")
        return []

    # Save the current sys.modules state
    original_modules = sys.modules.copy()

    try:
        with ChangeDirectoryAndPath(module_path):
            module = importlib.import_module("tool")
            export_tools = getattr(module, "export_tools")
            valid_tools = []
            for tool in export_tools:
                assert isinstance(tool, langchain_core.tools.StructuredTool) or isinstance(
                    tool, types.FunctionType
                ), f"Tool is not a StructuredTool or function: {tool}"
                if isinstance(tool, types.FunctionType) and not isinstance(
                    tool, langchain_core.tools.StructuredTool
                ):
                    valid_tools.append(_tool(tool))
            export_tools = valid_tools

    except Exception as e:
        print(f"Error loading tool {tool_id}: {e}")
        return []

    # Unload modules and restore sys.modules state
    importlib.invalidate_caches()
    for key in list(sys.modules.keys()):
        if key not in original_modules:
            del sys.modules[key]

    for tool in export_tools:
        tool.func = wrapped_tool(tool, module_path)

    return export_tools

==> pycoze-0.1.96-py3-none-any.whl: pycoze/access/tool_for_bot.py <==
import sys
import os
import importlib
from langchain.agents import tool as to_agent_tool
import types
import langchain_core
from .lib import ChangeDirectoryAndPath, ModuleManager



def wrapped_tool(tool, module_path):
    """Wrap the tool function to include additional logging and path management."""
    original_tool_function = tool.func

    def _wrapped_tool(*args, **kwargs):
        print(f"调用了{tool.name}")
        with ChangeDirectoryAndPath(module_path):
            result = original_tool_function(*args, **kwargs)
        print(f"{tool.name}调用完毕,结果为:", result)
        return result

    return _wrapped_tool


def import_tools(tool_id):
    """Import tools from a specified tool_id."""
    tool_base_path = "../../tool"
    module_path = os.path.join(tool_base_path, tool_id)
    module_path = os.path.normpath(os.path.abspath(module_path))

    if not os.path.exists(module_path):
        print(f"Tool {tool_id} not found")
        return []

    try:
        with ModuleManager(module_path) as manager:
            module = importlib.import_module("tool")
            export_tools = getattr(module, "export_tools")
            valid_tools = []
            for tool in export_tools:
                assert isinstance(tool, langchain_core.tools.StructuredTool) or isinstance(
                    tool, types.FunctionType
                ), f"Tool is not a StructuredTool or function: {tool}"
                if not isiisinstance(tool, langchain_core.tools.StructuredTool):
                    tool = to_agent_tool(tool)
                valid_tools.append(to_agent_tool(tool))
            export_tools = valid_tools

    except Exception as e:
        print(f"Error loading tool {tool_id}: {e}")
        return []

    for tool in export_tools:
        tool.func = wrapped_tool(tool, module_path)

    return export_tools
